@@ -6,9 +6,11 @@ from typing import Dict, List, Sequence, Tuple
 
 from gpt_index.async_utils import run_async_tasks
 from gpt_index.data_structs.data_structs import IndexGraph, Node
+from gpt_index.indices.node_utils import get_text_splits_from_document
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.utils import get_sorted_node_list, truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
+from gpt_index.langchain_helpers.text_splitter import TextSplitter
 from gpt_index.prompts.prompts import SummaryPrompt
 from gpt_index.schema import BaseDocument
 
@@ -27,6 +29,7 @@ class GPTTreeIndexBuilder:
         summary_prompt: SummaryPrompt,
         llm_predictor: LLMPredictor,
         prompt_helper: PromptHelper,
+        text_splitter: TextSplitter,
         use_async: bool = False,
     ) -> None:
         """Initialize with params."""
@@ -36,6 +39,7 @@ class GPTTreeIndexBuilder:
         self.summary_prompt = summary_prompt
         self._llm_predictor = llm_predictor
         self._prompt_helper = prompt_helper
+        self._text_splitter = text_splitter
         self._use_async = use_async
 
     def _get_nodes_from_document(
@@ -43,12 +47,10 @@ class GPTTreeIndexBuilder:
     ) -> Dict[int, Node]:
         """Add document to index."""
         # NOTE: summary prompt does not need to be partially formatted
-        text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
-            self.summary_prompt, self.num_children
-        )
-        text_chunks = text_splitter.split_text(
-            document.get_text(), extra_info_str=document.extra_info_str
+        text_splits = get_text_splits_from_document(
+            document=document, text_splitter=self._text_splitter
         )
+        text_chunks = [text_split.text_chunk for text_split in text_splits]
         doc_nodes = {
             (start_idx + i): Node(
                 text=t,
