@@ -1,10 +1,11 @@
 """Retrieve query."""
-
+import logging
 from typing import List, Optional
 
 from gpt_index.data_structs.data_structs import IndexGraph, Node
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.embedding_utils import SimilarityTracker
+from gpt_index.indices.query.schema import QueryBundle
 from gpt_index.indices.utils import get_sorted_node_list
 
 
@@ -29,14 +30,15 @@ class GPTTreeIndexRetQuery(BaseGPTIndexQuery[IndexGraph]):
 
     def _get_nodes_for_response(
         self,
-        query_str: str,
-        verbose: bool = False,
+        query_bundle: QueryBundle,
         similarity_tracker: Optional[SimilarityTracker] = None,
     ) -> List[Node]:
         """Get nodes for response."""
-        print(f"> Starting query: {query_str}")
+        logging.info(f"> Starting query: {query_bundle.query_str}")
         node_list = get_sorted_node_list(self.index_struct.root_nodes)
-        text_qa_template = self.text_qa_template.partial_format(query_str=query_str)
+        text_qa_template = self.text_qa_template.partial_format(
+            query_str=query_bundle.query_str
+        )
         node_text = self._prompt_helper.get_text_from_nodes(
             node_list, prompt=text_qa_template
         )
