@@ -1,11 +1,12 @@
 """Summarize query."""
 
-
+import logging
 from typing import Any, List, Optional, cast
 
 from gpt_index.data_structs.data_structs import IndexGraph, Node
 from gpt_index.indices.query.base import BaseGPTIndexQuery
 from gpt_index.indices.query.embedding_utils import SimilarityTracker
+from gpt_index.indices.query.schema import QueryBundle
 from gpt_index.indices.response.builder import ResponseMode
 from gpt_index.indices.utils import get_sorted_node_list
 
@@ -49,12 +50,11 @@ class GPTTreeIndexSummarizeQuery(BaseGPTIndexQuery[IndexGraph]):
 
     def _get_nodes_for_response(
         self,
-        query_str: str,
-        verbose: bool = False,
+        query_bundle: QueryBundle,
         similarity_tracker: Optional[SimilarityTracker] = None,
     ) -> List[Node]:
         """Get nodes for response."""
-        print(f"> Starting query: {query_str}")
+        logging.info(f"> Starting query: {query_bundle.query_str}")
         index_struct = cast(IndexGraph, self._index_struct)
         sorted_node_list = get_sorted_node_list(index_struct.all_nodes)
         return sorted_node_list
