@@ -13,8 +13,6 @@ from typing import List, Optional
 from gpt_index.readers.base import BaseReader
 from gpt_index.readers.schema.base import Document
 
-logger = logging.getLogger(__name__)
-
 
 async def read_channel(
     discord_token: str, channel_id: int, limit: Optional[int], oldest_first: bool
@@ -33,7 +31,7 @@ async def read_channel(
     class CustomClient(discord.Client):
         async def on_ready(self) -> None:
             try:
-                print(f"{self.user} has connected to Discord!")
+                logging.info(f"{self.user} has connected to Discord!")
                 channel = client.get_channel(channel_id)
                 # only work for text channels for now
                 if not isinstance(channel, discord.TextChannel):
@@ -57,7 +55,7 @@ async def read_channel(
                         ):
                             messages.append(thread_msg)
             except Exception as e:
-                print("Encountered error: " + str(e))
+                logging.error("Encountered error: " + str(e))
             finally:
                 await self.close()
 
@@ -147,6 +145,6 @@ class DiscordReader(BaseReader):
 
 if __name__ == "__main__":
     reader = DiscordReader()
-    print("initialized reader")
+    logging.info("initialized reader")
     output = reader.load_data(channel_ids=[1057178784895348746], limit=10)
-    print(output)
+    logging.info(output)
