@@ -1,6 +1,8 @@
 """Test docstore."""
 
-from gpt_index.data_structs.data_structs import Node
+from typing import Dict, Type
+
+from gpt_index.data_structs.data_structs import IndexStruct, Node
 from gpt_index.docstore import DocumentStore
 from gpt_index.readers.schema.base import Document
 
@@ -10,6 +12,8 @@ def test_docstore() -> None:
     doc = Document("hello world", doc_id="d1", extra_info={"foo": "bar"})
     node = Node("my node", doc_id="d2", node_info={"node": "info"})
 
+    type_to_struct: Dict[str, Type[IndexStruct]] = {"node": Node}
+
     # test get document
     docstore = DocumentStore.from_documents([doc, node])
     gd1 = docstore.get_document("d1")
@@ -40,5 +44,5 @@ def test_docstore() -> None:
         },
     }
 
-    docstore_loaded = DocumentStore.load_from_dict(doc_dict)
+    docstore_loaded = DocumentStore.load_from_dict(doc_dict, type_to_struct)
     assert docstore_loaded == docstore
